function [Result]=NormalizedBlockiness(Image)
% Normalized blockiness of an RGB image (double precision, [0,1] range)
% Result is in the interval [-1,1] (1 means maximum blockiness)
% Optimal Q for RDCT is attained when Result is about 0.0040479
% Result is zero for a constant image
% Result is approximately zero for an image with random noise (with every pixel
%   independent from all the others)
% Result is approximately zero for a natural uncompressed image
Result=0;

for NdxChannel=1:3
    B1=blockiness(Image(:,:,NdxChannel));
    B2=blockiness(circshift(Image(:,:,NdxChannel),[4 4]));
    Result=Result+...
        B1-B2;
end
Result=Result/3;
end

function [ B ] = blockiness( image )
image=double(image);
M=size(image,1); %height of image
N=size(image,2); %width of image

MySum=0;
for i=1:(M-1)/8 %for all possible 8x8 blocks row-wise
    temp=image(8*i,1:N); %put all elements of 8*ith row in a vector
    temp2=image(8*i+1,1:N); %put all elements of 8*ith+1 row in a vector
    MySum=MySum+sum(abs(temp-temp2)); %sum of the absolute value difference
    %of the two vectors
end

for j=1:(N-1)/8 %for all possible 8x8 blocks row-wise
    temp=image(1:M,8*j); %put all elements of 8ith column in a
    %vector
    temp2=image(1:M,8*j+1); %put all elements of 8ith+1 column in a
    %vector
    MySum=MySum+sum(abs(temp-temp2)); %sum of the absolute value difference
    %of the two vectors
end

NumElems=N*floor((M-1)/8)+M*floor((N-1)/8);
B=MySum/NumElems; %add the two sums
end

    