% X is the matrix where the rows are the patterns and the columns are the 
% features. Last column corresponds to the class of each pattern.
% 'trainRatio' is the percentage of data to be used in the training phase. 
function [trainV,valV,testV] = TrainTestData2(X,trainRatio)

if ischar(X)
  switch (X)
    case 'info'
      info.name = mfilename;
      info.title = 'Random in classes';
      info.type = 'Data Division';
      info.version = 6;
      trainV = info;
    case 'name'
      trainV = 'Random in classes';
    case 'fpdefaults'
    case 'defaultParam'        
      defaults = struct;
      defaults.trainRatio = 0.6;
      defaults.testRatio = 0.2;
      defaults.valRatio = 0.2;
      defaults.T = 0;
      trainV = defaults;

      otherwise
      error('TrainTestData:Arguments','Unrecognized string: %s',X);
  end
  return
end

%% DEFAULTS
if (nargin == 1), trainRatio = TrainTestData2('fpdefaults'); end

indices = trainRatio.T{1};
T = trainRatio.T{2};

testV = [];
for i=1:length(T.Test)
    idx = T.Test(i);
    ini = indices(idx,1);
    fin = indices(idx,2);
    Q = X(ini:fin);
    perm = randperm(length(Q));
    Q = Q(perm);
    testV = [testV Q];
end

valV = [];
for i=1:length(T.Val)
    idx = T.Val(i);
    ini = indices(idx,1);
    fin = indices(idx,2);
    Q = X(ini:fin);
    perm = randperm(length(Q));
    Q = Q(perm);
    valV = [valV Q];
end

trainV = [];
for i=1:length(T.Train)
    idx = T.Train(i);
    ini = indices(idx,1);
    fin = indices(idx,2);
    Q = X(ini:fin);
    perm = randperm(length(Q));
    Q = Q(perm);
    trainV = [trainV Q];
end

